##
## Copyright (C) 2017 Lenovo, Inc.
## Licensed under the Apache License, Version 2.0 (the "License"); 
## you may not use this file except in compliance with the License. 
## You may obtain a copy of the License at 
##       http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software 
## distributed under the License is distributed on an "AS IS" BASIS, 
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and 
## limitations under the License.
##
require 'rest-client'
require 'yaml'
require_relative 'rest_utils'
require 'json'

def form_hdr(conn)
	hdr = {}
	tmp_ckie = 'auth_cookie='+ conn.getCookie + ';user=' + conn.getUser + '; Max-Age=3600; Path=/'
   	hdr['Cookie'] = tmp_ckie
   	hdr['Content-type'] = 'application/json'
   	return hdr
end	

def form_url(conn, url)
	url = conn.getTransport +  '://' + conn.getIp + ':' + conn.getPort + url
	return url
end

##
## The Connect class provides a class implementation and methods for establishing node connections and
## initializations. This class presents an abstraction
## 

class Connect
	
	# This function is used to initialise node paramters and establish connection with the given paramters.
        # 
        # 
        #  parameters:
        #  file   :config file
        #
        #  return: Connect object 		
	def initialize(params)
		#params = YAML.load_file(file)
		@transport = params['transport']
		@port      = params['port']
		@ip        = params['ip']
		@user      = params['user']
		@password  = params['password']
		@cookie    = ''
                #Puppet.notice("transport  = #{@ip}")
                if @transport == 'http'
			@url       = @transport + '://' + @ip + ':' + @port + '/nos/api/login/'
                end
                if @transport == 'https'
			@url       = @transport + '://' + @ip + '/nos/api/login/'
                end
		
		begin
			RestClient::Request.execute(method: :get, url: @url, user: @user, password: @password, timeout: 10, :verify_ssl => false)
		rescue RestClient::Unauthorized, RestClient::Forbidden => err
  			@cookie =  err.response.cookies['auth_cookie']
		end
		
		@hdr = {}
		tmp_ckie = 'auth_cookie=' + @cookie + ';user=' + @user + '; Max-Age=3600; Path=/'
		@hdr['Cookie'] = tmp_ckie
		resp = RestClient::Request.execute(method: :get, url: @url, headers: @hdr, user: @user, password: @password, timeout: 10, :verify_ssl => false)
		@cookie = resp.cookies['auth_cookie']
		@hdr['Content-type'] = 'application/json'
                #Puppet.notice("resp  = #{resp}")

	end

        # This API returns the facts asspociated with the URL being supplied.
        #
        #  parameters:
        #  facts_url - string
        #  any extra arguemnts
        #
        #  return: facts data - in json format
        def getFacts(facts_url, args={})
                #Puppet.notice("URL is   = #{facts_url}")
                url = form_url(self, facts_url)
                hdr = form_hdr(self)
                resp = Rest.get(self, url, hdr)
                #Puppet.notice("Response  = #{resp}")
                return resp.to_json
        end

	# This API returns Transport protocol for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: transport - string	
	def getTransport()
		return @transport
	end

	# This API returns Port for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: port - string	
	def getPort()
                return @port
	end
	
	# This API returns IP  for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: IP	- string
	def getIp()
                return @ip
	end
	
	# This API returns User for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: User	- string 
	def getUser()
		return @user
	end
	
	# This API returns Password for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: Password - string	
	def getPassword()
                return @password
	end
	
	# This API returns Cookie for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: Cookie - string
	def getCookie()
                return @cookie
	end

	# This API returns Header Info for the current node connection.
        # 
        # 
        #  parameters:
        #
        #  return: header - string	
	def getHdr()
		return @hdr
	end


end
