##
## Copyright (C) 2017 Lenovo, Inc.
## Licensed under the Apache License, Version 2.0 (the "License"); 
## you may not use this file except in compliance with the License. 
## You may obtain a copy of the License at 
##       http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software 
## distributed under the License is distributed on an "AS IS" BASIS, 
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and 
## limitations under the License.
##
require 'rest-client'
require 'json'

##
## The Rest class provides a class implementation and methods for executing REST methods such as GET, POST, PUT and DELETE  
## on the node. This class presents an abstraction
## 

class Rest
	# This API performs GET request for the given url and switch connection.
	#        
	#              
	# parameters:
	# conn - connection object to the node
	# url - URL for the GET request
	# hdr - header paramters for the GET request
	#                                                    
	# return: JSON response
	def self.get(conn, url, hdr)
		begin
                        resp = RestClient::Request.execute method: :get, url: url, headers: hdr, user: conn.getUser, password: conn.getPassword, timeout: 20 ,:verify_ssl => false
                        response = JSON.parse(resp)
                        response
                rescue RestClient::ExceptionWithResponse => err
                        puts err
			puts err.response.match(/<p>(.+)<\/p>/)[1]

                end
	
	end
	
	# This API performs PUT request for the given url and switch connection.
	#        
	#              
	# parameters:
	# conn - connection object to the node
	# url - URL for the PUT request
	# hdr - header paramters for the PUT request
	# params - JSON body for POST request
	#                                                    
	# return: JSON response
	def self.put(conn, url, hdr, params)
		begin
                        resp = RestClient::Request.execute method: :put, url: url, headers: hdr, payload: params, user: conn.getUser, password: conn.getPassword, timeout: 20 ,:verify_ssl => false
                        response = JSON.parse(resp)
                        response
		rescue RestClient::ExceptionWithResponse => err
                        puts err
			puts err.response.match(/<p>(.+)<\/p>/)[1]
                end

	end
	
	# This API performs POST request for the given url and switch connection.
	#        
	#              
	# parameters:
	# conn - connection object to the node
	# url - URL for the POST request
	# hdr - header paramters for the POST request
	# params - JSON body for POST request
	#                                                    
	# return: JSON response
	def self.post(conn, url, hdr, params)
		begin
                        resp = RestClient::Request.execute method: :post, url: url, headers: hdr, payload: params, user: conn.getUser, password: conn.getPassword, timeout: 20 ,:verify_ssl => false
                        response = JSON.parse(resp)
                        response
		rescue RestClient::ExceptionWithResponse => err
                        puts err
			puts err.response.match(/<p>(.+)<\/p>/)[1]


                end	
	end
	
	# This API performs DELETE request for the given url and switch connection.
	#        
	#              
	# parameters:
	# conn - connection object to the node
	# url - URL for the DELETE request
	# hdr - header paramters for the DELETE request
	#                                                    
	# return: JSON response
	def self.delete(conn, url, hdr)
		begin
                        resp = RestClient::Request.execute method: :delete, url: url, headers: hdr, user: conn.getUser, password: conn.getPassword, timeout: 20 ,:verify_ssl => false
                rescue RestClient::ExceptionWithResponse => err
                        puts err
			puts err.response.match(/<p>(.+)<\/p>/)[1]

                end

	end

end
